@@ -542,7 +542,7 @@ class DataClient(object):
     @staticmethod
     def upload_user_avatar(school_id, file_path, user_id):
         backbone = Backbone(school_id)
-        backbone.upload_user_avatar(file_path, user_id)
+        return backbone.upload_user_avatar(file_path, user_id)
 
     @staticmethod
     def upload_user_face(school_id, file_path, student_id=None, teacher_id=None):
@@ -550,7 +550,7 @@ class DataClient(object):
             return None
         data = {"student_id": student_id} if student_id else {"teacher_id": teacher_id}
         backbone = Backbone(school_id)
-        backbone.upload_user_face(file_path, data)
+        return backbone.upload_user_face(file_path, data)
 
 
 class DataClientV1(DataClient):
