@@ -657,10 +657,10 @@ class Backbone(object):
         return room_list
 
     def upload_user_avatar(self, file_path, user_id):
-        self.edtech_requester.upload_user_avatar(file_path, user_id)
+        return self.edtech_requester.upload_user_avatar(file_path, user_id)
 
     def upload_user_face(self, file_path, data):
-        self.nirvana_requester.upload_face_file(file_path, data)
+        return self.nirvana_requester.upload_face_file(file_path, data)
 
     def upload_meeting_rooms(self, meeting_rooms):
         self.wrap_student_map()
