@@ -1,5 +1,5 @@
 from ..models.base import BaseModel
-from ..utils.code import b64encode
+from ..utils.code import b64decode
 
 
 class GenderSet(object):
@@ -38,7 +38,7 @@ class Teacher(BaseModel):
                 "name": self.name,
                 "number": self.number,
                 "phone": self.phone,
-                "password": b64encode(self.password),
+                "password": self.password,
                 "school": self.school
                 }
         return data
@@ -75,8 +75,40 @@ class Student(BaseModel):
                 "name": self.name,
                 "number": self.number,
                 "phone": self.phone,
-                "password": b64encode(self.password),
+                "password": self.password,
                 "classof": self.classof,
                 "graduateat": self.graduateat,
                 "section": self.class_id or self.section}
         return data
+
+
+class EduOrgUser(BaseModel):
+
+    def __init__(self, *args, **kwargs):
+        self.uid = None
+        self.number = None
+        self.password = None
+        self.name = None
+        self.description = None
+        self.birthday = None
+        self.outer_id = None
+        self.email = None
+        self.gender = GenderSet.MALE
+        self.phone = None
+        self.job = None
+        super(EduOrgUser, self).__init__(*args, **kwargs)
+
+    @property
+    def sso_data(self):
+        data = {"birthday": self.birthday,
+                "description": self.description,
+                "outer_id": self.outer_id,
+                "email": self.email,
+                "gender": self.gender,
+                "name": self.name,
+                "number": self.number,
+                "phone": self.phone,
+                "password": self.password,
+                "job": self.job
+                }
+        return data
