@@ -19,7 +19,7 @@ TABLE_END_DATE = os.getenv("TABLE_END_DATE", "2020-01-12")
 TABLE_SEMESTER = os.getenv("TABLE_SEMESTER", "1")
 TABLE_YJS_SEMESTER = os.getenv("TABLE_YJS_SEMESTER", "第一学期")
 TABLE_YEAR = os.getenv("TABLE_YEAR", "2019-2020")
-SCHOOL_NAME = os.getenv("SCHOOL_NAME", "test_zz")
+SCHOOL_NAME = os.getenv("SCHOOL_NAME", "五楼229环境")
 SCHOOL_SEASON = os.getenv("SCHOOL_SEASON", "winter")
 SEMESTER_NAME = os.getenv("SEMESTER_NAME", "当前学期")
 REST_TABLE_NAME = os.getenv("REST_TABLE_NAME", "全校作息")
@@ -32,5 +32,5 @@ WINTER_MORNING_LIMIT = os.getenv("WINTER_MORNING_LIMIT", "12:30:00")
 WINTER_AFTERNOON_LIMIT = os.getenv("WINTER_AFTERNOON_LIMIT", "17:00:00")
 
 # redis
-REDIS_HOST = os.getenv("REDIS_HOST", "10.88.188.229")
-REDIS_PORT = int(os.getenv("REDIS_PORT", 16379))
+REDIS_HOST = os.getenv("REDIS_HOST", "10.51.67.67")
+REDIS_PORT = int(os.getenv("REDIS_PORT", 36379))
