@@ -25,32 +25,6 @@ def get_school_id():
     return code, school.get("uuid")
 
 
-# def transact_subject_data():
-#     logger.info("start subject data sync at {}".format(datetime.now()))
-#     # 学校数据
-#     code, school_id = get_school_id()
-#     if code or not school_id:
-#         logger.error("Error: get school id fail, now break transact next data.")
-#         return
-#
-#     # 课程科目数据
-#     # subject_data = query_subject_data(params={"NJ": ('>', 2015)})
-#     subject_data = query_subject_data()
-#     tmp_data = {}
-#     for d in subject_data:
-#         kcdm = d['KCDM']
-#         if not tmp_data.get(kcdm):
-#             tmp_data[kcdm] = d
-#     subject_data = tmp_data.values()
-#     # 课程科目数据
-#     for d in subject_data:
-#         subjects = subject_convert(data=d, school=school_id)
-#         code, data = client.create_subject(subjects)
-#         if code:
-#             logger.error("Code: {}, Msg: {}".format(code, data))
-#     logger.info("end subject data sync at {}".format(datetime.now()))
-
-
 def transact_section_data():
     logger.info("start section data sync at {}".format(datetime.now()))
     # 学校数据
@@ -122,28 +96,28 @@ def transact_student_data():
     today_year = datetime.now().year
     front_years = 6
     # 4.1 本科生数据
-    # for cut_year in range(front_years):
-    #     current_year = today_year - cut_year
-    #     page_index, row_index = 1, 1
-    #     while True:
-    #         bk_student_res = sdtu_requester.get_bk_student_list(page=page_index, pagesize=SDTU_PAGE_SIZE,
-    #                                                             params={"XZNJ": str(current_year)})
-    #         total_count = bk_student_res["total"]
-    #         current_rows = bk_student_res["data"]["Rows"]
-    #         for d in current_rows:
-    #             section_id = section_dict.get(d["BH"])
-    #             ecard = card_dict.get(d["XH"])
-    #             student = bk_student_convert(data=d, ecard=ecard, school=school_id, section=section_id)
-    #             if student.number in number_map:
-    #                 student.uid = number_map[student.number]
-    #             code, data = client.create_student(students=student)
-    #             if code:
-    #                 logger.error("Code: {}, Msg: {}".format(code, data))
-    #             logger.info("Already create {}/{} bks".format(row_index, total_count))
-    #             row_index += 1
-    #         if page_index * SDTU_PAGE_SIZE >= total_count:
-    #             break
-    #         page_index += 1
+    for cut_year in range(front_years):
+        current_year = today_year - cut_year
+        page_index, row_index = 1, 1
+        while True:
+            bk_student_res = sdtu_requester.get_bk_student_list(page=page_index, pagesize=SDTU_PAGE_SIZE,
+                                                                params={"XZNJ": str(current_year)})
+            total_count = bk_student_res["total"]
+            current_rows = bk_student_res["data"]["Rows"]
+            for d in current_rows:
+                section_id = section_dict.get(d["BH"])
+                ecard = card_dict.get(d["XH"])
+                student = bk_student_convert(data=d, ecard=ecard, school=school_id, section=section_id)
+                if student.number in number_map:
+                    student.uid = number_map[student.number]
+                code, data = client.create_student(students=student)
+                if code:
+                    logger.error("Code: {}, Msg: {}".format(code, data))
+                logger.info("Already create {}/{} bks".format(row_index, total_count))
+                row_index += 1
+            if page_index * SDTU_PAGE_SIZE >= total_count:
+                break
+            page_index += 1
     # 4.1 研究生数据
     for cut_year in range(front_years):
         current_year = today_year - cut_year
@@ -218,7 +192,7 @@ def transact_teacher_data():
 def start_data_sync():
     start_time = time.time()
     logger.info("start data sync at {}".format(datetime.now()))
-    # transact_section_data()
+    transact_section_data()
     transact_student_data()
     transact_teacher_data()
     logger.info("end data sync at {}".format(datetime.now()))
