@@ -343,11 +343,11 @@ class CourseTableSync(BaseSync):
     def sync(self):
         self.record(">>>Start course sync")
         t1 = time.time()
-        self.get_bk_course()
+        # self.get_bk_course()
         self.combine_course()
         self.record(">>>Total have {} courses".format(len(self.course_map)))
-        if self.need_relate_student:
-            self.relate_student()
+        # if self.need_relate_student:
+        #     self.relate_student()
         self.record(">>>Get yjs course")
         yjs_course = self.get_yjs_course()
         self.course_map.update(yjs_course)
